@@ -5,9 +5,18 @@ use rlib '../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Backtrace;
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
-use strict;
 
-use vars qw(@ISA); @ISA = @CMD_ISA; 
+unless (defined @ISA) {
+    eval <<"EOE";
+use constant ALIASES    => qw(bt where T);
+use constant CATEGORY   => 'stack';
+use constant SHORT_HELP => 'Print backtrace of stack frames';
+use constant MIN_ARGS  => 0;   # Need at least this many
+use constant MAX_ARGS  => 1;   # Need at most this many - undef -> unlimited.
+EOE
+}
+
+use strict; use vars qw(@ISA); @ISA = @CMD_ISA; 
 use vars @CMD_VARS;  # Value inherited from parent
 
 our $NAME = set_name();
@@ -26,12 +35,6 @@ Examples:
    ${NAME} 2  # Print only the top two entries
 HELP
 
-use constant ALIASES    => qw(bt where T);
-use constant CATEGORY   => 'stack';
-use constant SHORT_HELP => 'Print backtrace of stack frames';
-our $MIN_ARGS    = 0;  # Need at least this many
-our $MAX_ARGS     = 1;  # Need at most this many
-
 sub complete($$)
 { 
     my ($self, $prefix) = @_;
