@@ -5,9 +5,19 @@ use rlib '../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Down;
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
-use strict;
 
-use vars qw(@ISA); @ISA = qw(Devel::Trepan::CmdProcessor::Command);
+unless (defined @ISA) {
+    eval <<"EOE";
+use constant ALIASES    => qw(u);
+use constant CATEGORY   => 'stack';
+use constant SHORT_HELP => 'Move frame in the direction of the least recent frame';
+use constant NEED_STACK => 1;
+use constant MIN_ARGS  => 0;  # Need at least this many
+use constant MAX_ARGS  => 1;  # Need at most this many - undef -> unlimited.
+EOE
+}
+
+use strict; use vars qw(@ISA); @ISA = @CMD_ISA;
 use vars @CMD_VARS;  # Value inherited from parent
 
 our $NAME = set_name();
@@ -20,12 +30,6 @@ is the most recent frame. If no count is given, move down 1.
 See also 'up' and 'frame'.
 HELP
 
-use constant ALIASES    => qw(u);
-use constant CATEGORY   => 'stack';
-use constant SHORT_HELP => 'Move frame in the direction of the least recent frame';
-our $MAX_ARGS     = 1;  # Need at most this many
-our $NEED_STACK   = 1;
-
 sub complete($$)
 { 
     my ($self, $prefix) = @_;
