@@ -3,12 +3,25 @@ use warnings; no warnings 'redefine';
 use feature 'switch';
 use rlib '../../../..';
 
+use Devel::Trepan::DB::LineCache;
+use Devel::Trepan::DB::Sub;
+
 package Devel::Trepan::CmdProcessor::Command::Edit;
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
-use strict;
+unless (defined @ISA) {
+    eval <<"EOE";
+use constant ALIASES    => ('e');
+use constant CATEGORY   => 'files';
+use constant SHORT_HELP => 'Invoke an editor on some source code';
+use constant NEED_STACK => 0;
+use constant MIN_ARGS   => 0;  # Need at least this many
+use constant MAX_ARGS   => 2;  # Need at most this many - undef -> unlimited.
+EOE
+}
 
-use vars qw(@ISA); @ISA = @CMD_ISA; 
-use vars @CMD_VARS;  # Value inherited from parent
+use strict;
+our @ISA = @CMD_ISA;  # value inherited from parent
+use vars @CMD_VARS;   # value inherited from parent
 
 our $NAME = set_name();
 our $HELP = <<"HELP";
@@ -28,12 +41,14 @@ ${NAME} test.rb    # Edit test.rb, line 1
 ${NAME} test.rb 10 # Edit test.rb  line 10
 HELP
 
-use constant ALIASES    => ('e');
-use constant CATEGORY   => 'files';
-use constant SHORT_HELP => 'Invoke an editor on some source code';
-our $NEED_STACK   = 0;
-our $MAX_ARGS     = 2;  # Need at most this many
-
+# FIXME: include line numbers. Should we include all files? 
+# Combine with BREAK completion.
+sub complete($$)
+{
+    my ($self, $prefix) = @_;
+    my @completions = sort ('.', DB::LineCache::file_list());
+    Devel::Trepan::Complete::complete_token(\@completions, $prefix);
+}
 
 # This method runs the command
 sub run($$)
@@ -42,12 +57,12 @@ sub run($$)
     my ($filename, $line_number);
     given (scalar @$args) {
 	when (1) {
-	    $filename     = $self->{proc}{frame}{file};
-	    $line_number  = $self->{proc}{frame}{line};
+	    $filename     = $self->{proc}->filename;
+	    $line_number  = $self->{proc}->line;
 	} when(2) {
 	    $line_number = $self->{proc}->get_int_noerr($args->[1]);
 	    if (defined $line_number) {
-		$filename = $self->{proc}{frame}{file};
+		$filename = $self->{proc}->filename;
 	    } else {
 		$filename = $args->[1];
 		$line_number = 1;
@@ -56,6 +71,7 @@ sub run($$)
 	    ($line_number, $filename) =  ($args->[2], $args->[1]);
 	} default {
 	    $self->errmsg("edit needs at most 2 args.");
+	    return;
 	}
     }
     my $editor = $ENV{'EDITOR'} || '/bin/ex';
@@ -75,6 +91,19 @@ unless (caller) {
     require Devel::Trepan::CmdProcessor;
     my $proc = Devel::Trepan::CmdProcessor->new(undef, 'bogus');
     my $cmd = __PACKAGE__->new($proc);
+    sub create_frame() {
+    	my ($pkg, $file, $line, $fn) = caller(0);
+	return [
+	    {
+		 file      => $file,
+		 fn        => $fn,
+		 line      => $line,
+		 pkg       => $pkg,
+	    }];
+    }
+    my $frame_ary = create_frame();
+    $proc->frame_setup($frame_ary);
+
     $cmd->run([$NAME]);
     $cmd->run([$NAME, '7']);
     $cmd->run([$NAME, __FILE__, '10']);
