@@ -15,7 +15,7 @@ use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
 our $HELP = "Show the value about to be returned";
 our $MIN_ABBREV = length('ret');
-our $NEED_STACK = 1;
+use constant NEED_STACK => 1;
 
 use Data::Dumper;
 
@@ -30,14 +30,14 @@ sub run($$)
     }
     my $ret_type = $proc->{dbgr}->return_type();
     if ('undef' eq $ret_type) {
-	$proc->msg("Return value is <undef>");
+	$proc->msg("Return value for $DB::_[0] is <undef>");
     } elsif ('array' eq $ret_type) {
-	$proc->msg("Return array value:");
+	$proc->msg("Return array value for $DB::_[0] is:");
 	my @ret = $proc->{dbgr}->return_value();
 	$proc->msg(Dumper(@ret));
     } elsif ('scalar' eq $ret_type) {
 	my $ret = $proc->{dbgr}->return_value();
-	$proc->msg("Return value: $ret");
+	$proc->msg("Return value for $DB::_[0] is: $ret");
     }
 }
 
