@@ -8,15 +8,17 @@ package Devel::Trepan::CmdProcessor::Command::Macro;
 use English qw( -no_match_vars );
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
 unless (defined(@ISA)) {
-    eval "use constant CATEGORY   => 'support';";
-    eval "use constant SHORT_HELP => 'Define a macro';";
+    eval <<'EOE';
+use constant CATEGORY   => 'support';
+use constant SHORT_HELP => 'Define a macro';
+use constant MIN_ARGS   => 3; # Need at least this many
+use constant MAX_ARGS   => undef; # Need at most this many - undef -> unlimited.
+EOE
 }
 
 use strict; use vars qw(@ISA); @ISA = @CMD_ISA;
 use vars @CMD_VARS;  # Value inherited from parent
 
-our $MIN_ARGS = 3;
-our $MAX_ARGS = undef;
 our $NAME = set_name();
 our $HELP = <<"HELP";
 ${NAME} MACRO-NAME sub { ... }
@@ -90,10 +92,10 @@ unless (caller) {
     # 		      "#{cmd.name} bad2 1+2") {
     # 	@args = split $cmdline;
     # 	$cmd_argstr = cmdline[args[0].size..-1].lstrip;
-    # 	$cmdproc->instance_variable_set('@cmd_argstr', $cmd_argstr);
+    # 	$cmdproc->{cmd_argstr} = $cmd_argstr;
     # 	$cmd->run(@args);
     # }
-    # print $cmdproc->{macros};
+    # print $cmdproc->{macros}, "\n";
 }
 
 1;
