@@ -94,9 +94,43 @@ sub next_token($$)
     return ($next_blank_pos, substr($str, $next_nonblank_pos, $token_size));
 }
 
+# From Term::ReadLine::readline.pm
+
+##
+## For use in passing to completion_matches(), returns a list of
+## filenames that begin with the given pattern.  The user of this package
+## can set $rl_completion_function to 'rl_filename_list' to restore the
+## default of filename matching if they'd changed it earlier, either
+## directly or via &rl_basic_commands.
+##
+sub filename_list(;$$)
+{
+    my ($pattern, $add_suffix) = @_;
+    $pattern //= ''; $add_suffix //= 0;
+    # $pattern = glob($pattern) if substr($pattern, 0, 1) = '~';
+    my @files = (<$pattern*>);
+    if ($add_suffix) {
+	foreach (@files) {
+	    if (-l $_) {
+		$_ .= '@';
+	    } elsif (-d _) {
+		$_ .= '/';
+	    } elsif (-x _) {
+		$_ .= '*';
+	    } elsif (-S _ || -p _) {
+		$_ .= '=';
+	    }
+	}
+    }
+    return @files;
+}
+
+
 unless (caller) {
     my $hash_ref = {'ab' => 1, 'aac' => 2, 'aa' => 3, 'b' => 4};
     my @cmds = keys %{$hash_ref};
+    printf("complete_token(@cmds, '') => %s\n",
+	   join(', ', complete_token(\@cmds, '')));
     printf("complete_token(@cmds, 'a') => %s\n",
 	   join(', ', complete_token(\@cmds, 'a')));
     printf("complete_token(@cmds, 'b') => %s\n",
@@ -115,6 +149,12 @@ unless (caller) {
 	my @ary = next_token($x, $pos);
 	printf "next_token($pos) = %d, '%s'\n", $ary[0], $ary[1];
     }
+    print "List of filenames:\n";
+    print join(', ', filename_list), "\n";
+    print "List of filenames beginning with C:\n";
+    print join(', ', filename_list('C')), "\n";
+    # FIXME: We don't handle ~ expansion right now.
+    #  print "List of filenames expanded from ~\n";
 }
 
 1;
